@@ -225,9 +225,9 @@ void loadNextImage ()
 				pic = (unsigned char *)malloc (text_x * text_y);
 
 			image_info = CloneImageInfo ((ImageInfo *) NULL);
-			image_info->size = AcquireMemory(sizeof("90x70"));
+			image_info->size = AcquireMagickMemory(sizeof("90x70"));
 			strcpy(image_info->size, "90x70");
-			image = AllocateImage(image_info);
+			image = AcquireImage(image_info);
 
 			ImportImagePixels(image, 0, 0, 90, 70, "I", CharPixel, (unsigned char *)(pics + ((random () & 15) * (90 * 70))));
 
